
use "R:\C02 - ELASTIC DATA\ELASTIC EVS\EVS - DTA GF3\ELASTIC_EVS_GF3_3R05_HH_F_SQ_DEU.dta", clear
set more off
	

// -------------------------------------------------------------------------------------------------
// Rename EVS-Vars -> SOEP-Vars
// -------------------------------------------------------------------------------------------------

rename 	hhne_ip 	hincNetY
rename  hhnv_p 		hwTotNW
rename 	ersparnis_p	hsavingM
gen 	hincomeM = 	hincNetY
rename 	hhrf 		sw
rename 	surveyjahr	year


// -------------------------------------------------------------------------------------------------
// Data cleansing
// -------------------------------------------------------------------------------------------------
drop if 			hincNetY == 0
drop if 			hincomeM < 0
*drop if 			hsavingM < 0
*drop if 			hhne_v_p < 0 


	
/***************************************************************************************
*							/* + + + DATAPREP AUX VARS + + + */    					   *
***************************************************************************************/	
	
	
	
		*** select year
		global year 2003 2008 2013
	
	
	
/* + + + Income and wealth classes + + + */	
	
	*** deciles, vingtiles and percentiles of income
		set more off	
		foreach q of numlist 10 20 100 {
			foreach var in hincNetY {
					gen c`q'_`var' = .
					foreach k of numlist /*1996/2012*/ $year {
						xtile helpclass`k' = `var' [aw = sw] if year == `k', nq(`q')	
						replace c`q'_`var' = helpclass`k' if year == `k' 				// c10_hincNetY gibt an, in welchem Einkommensdezil/-vingtil usw. die HHe liegen.
					}
					drop helpclass*
			}
		}			
*		
	
	*** deciles, vingtiles and percentiles of wealth
		set more off
		foreach q of numlist 10 20 100 {
			foreach var in hwTotNW {
					gen c`q'_`var' = .
					foreach k of numlist /*2002(5)2012*/ $year {
						xtile helpclass`k' = `var' [aw = sw] if year == `k', nq(`q') 	
						replace c`q'_`var' = helpclass`k' if year == `k' 				// c10_hwTotNW gibt an, in welchem Vermögensdezil/-vingtil usw. die HHe liegen.
					}
					drop helpclass*
			}
		}			
*	



/* + + total savings + + */
	
		*** for wealth (without wealth missings)
		set more off
		gen totsavW =.
		foreach k of numlist /*2002(5)2012*/ $year {
			sum hsavingM [aw = sw] if year == `k' & hwTotNW !=. 	
			replace totsavW = r(sum) if year == `k' & hwTotNW !=. 	// totsavW = total savin amount per year (weighted, constant over all hhs)
		}

	
		*** for income (including)
		set more off
		gen totsavI =.
		foreach k of numlist /*1996/2012*/ $year {
			sum hsavingM [aw=sw] if year == `k'
			replace totsavI = r(sum) if year == `k' 												// total saving amount per year (weighted, constant across all hhs)
		}




/* + + Shares in total income + + */
	
		*** for wealth (without wealth missings)
		set more off
		gen tothincW =.
		foreach k of numlist /*2002(5)2012*/ $year {
			sum hincNetY [aw = sw] if year == `k' & hwTotNW !=. 	
			replace tothincW = r(sum) if year == `k' & hwTotNW !=. 	
		}
		gen sum_c10_hincW =.
		foreach q of numlist 1/10 {
			foreach k of numlist /*2002(5)2012*/ $year {
				sum hincNetY [aw = sw] if year == `k' & c10_hwTotNW == `q' & hwTotNW !=.
				replace sum_c10_hincW = r(sum) if year == `k' & c10_hwTotNW == `q' & hwTotNW !=. 	// sum_c10_hsavingW = saving amount per WEALTH decile (weighted, constant within wealth deciles)
			}
		}			
		gen sum_c20_hincW =.
		foreach q of numlist 1/20 {
			foreach k of numlist /*2002(5)2012*/ $year {
				sum hincNetY [aw = sw] if year == `k' & c20_hwTotNW == `q' & hwTotNW !=.
				replace sum_c20_hincW = r(sum) if year == `k' & c20_hwTotNW == `q' & hwTotNW !=. 	// sum_c20_hsavingW = saving amount per wealth vingtile (weighted, constant within wealth  deciles)
			}
		}		
		gen sum_c100_hincW =.
		foreach q of numlist 1/100 {
			foreach k of numlist /*2002(5)2012*/ $year {
				sum hincNetY [aw = sw] if year == `k' & c100_hwTotNW == `q' & hwTotNW !=.
				replace sum_c100_hincW = r(sum) if year == `k' & c100_hwTotNW == `q' & hwTotNW !=. 	// sum_c10_hsavingW = saving amount per wealth percentile (weighted, constant within wealth  deciles)
			}
		}		
		*** special groups
		gen sum_top1_hincW =.
			foreach k of numlist /*1996/2012*/ $year {
				sum hincNetY [aw=sw] if year == `k' & c100_hwTotNW == 100
				replace sum_top1_hincW = r(sum) if year == `k' 										// analog oben
			}
		gen sum_top5less1_hincW =.
			foreach k of numlist /*1996/2012*/ $year {
				sum hincNetY [aw=sw] if year == `k' & c20_hwTotNW == 20 & c100_hwTotNW != 100
				replace sum_top5less1_hincW = r(sum) if year == `k'
			}			
		gen sum_top10less5_hincW =.
			foreach k of numlist /*1996/2012*/ $year {
				sum hincNetY [aw=sw] if year == `k' & c10_hwTotNW == 10 & c20_hwTotNW != 20
				replace sum_top10less5_hincW = r(sum) if year == `k'
			}			
*	

	
	
		*** for income (including)
		set more off
		gen tothincI =.
		foreach k of numlist /*1996/2012*/ $year {
			sum hincNetY [aw=sw] if year == `k'
			replace tothincI = r(sum) if year == `k' 												// total saving amount per year (weighted, constant across all hhs)
		}
	*
		gen sum_c10_hincI =.		
		foreach q of numlist 1/10 {
			foreach k of numlist /*1996/2012*/ $year {
				sum hincNetY [aw=sw] if year == `k' & c10_hincNetY == `q'
				replace sum_c10_hincI = r(sum) if year == `k' & c10_hincNetY == `q' 				// saving amount per INCOME decile (weighted, constant within income deciles)
			}
		}	
		gen sum_c20_hincI =.
		foreach q of numlist 1/20 {
			foreach k of numlist 1996/2012 {
				sum hincNetY [aw=sw] if year == `k' & c20_hincNetY == `q'
				replace sum_c20_hincI = r(sum) if year == `k' & c20_hincNetY == `q' 				// analog für Vingtile
			}
		}	
		gen sum_c100_hincI =.
		foreach q of numlist 1/100 {
			foreach k of numlist /*1996/2012*/ $year {
				sum hincNetY [aw=sw] if year == `k' & c100_hincNetY == `q'
				replace sum_c100_hincI = r(sum) if year == `k' & c100_hincNetY == `q' 			// wie oben
			}
		}	
		*** special groups
		gen sum_top1_hincI =.
			foreach k of numlist /*1996/2012*/ $year {
				sum hincNetY [aw=sw] if year == `k' & c100_hincNetY == 100
				replace sum_top1_hincI = r(sum) if year == `k'
			}
		gen sum_top5less1_hincI =.
			foreach k of numlist /*1996/2012*/ $year {
				sum hincNetY [aw=sw] if year == `k' & c20_hincNetY == 20 & c100_hincNetY != 100
				replace sum_top5less1_hincI = r(sum) if year == `k'
			}			
		gen sum_top10less5_hincI =.
			foreach k of numlist /*1996/2012*/ $year {
				sum hincNetY [aw=sw] if year == `k' & c10_hincNetY == 10 & c20_hincNetY != 20
				replace sum_top10less5_hincI = r(sum) if year == `k'
			}			
*			



/* + + Shares in total wealth + + */
	
		*** for wealth (without wealth missings)
		set more off
		gen tothwealthW =.
		foreach k of numlist /*2002(5)2012*/ $year {
			sum hwTotNW [aw = sw] if year == `k' & hwTotNW !=. 
			replace tothwealthW = r(sum) if year == `k' & hwTotNW !=.  	
		}
		gen sum_c10_hwealthW =.
		foreach q of numlist 1/10 {
			foreach k of numlist /*2002(5)2012*/ $year {
				sum hwTotNW [aw = sw] if year == `k' & c10_hwTotNW == `q' & hwTotNW !=.
				replace sum_c10_hwealthW = r(sum) if year == `k' & c10_hwTotNW == `q' & hwTotNW !=. 	// sum_c10_hsavingW = saving amount per WEALTH decile (weighted, constant within wealth deciles)
			}
		}			
		gen sum_c20_hwealthW =.
		foreach q of numlist 1/20 {
			foreach k of numlist /*2002(5)2012*/ $year {
				sum hwTotNW [aw = sw] if year == `k' & c20_hwTotNW == `q' & hwTotNW !=.
				replace sum_c20_hwealthW = r(sum) if year == `k' & c20_hwTotNW == `q' & hwTotNW !=. 	// sum_c20_hsavingW = saving amount per wealth vingtile (weighted, constant within wealth  deciles)
			}
		}		
		gen sum_c100_hwealthW =.
		foreach q of numlist 1/100 {
			foreach k of numlist /*2002(5)2012*/ $year {
				sum hwTotNW [aw = sw] if year == `k' & c100_hwTotNW == `q' & hwTotNW !=.
				replace sum_c100_hwealthW = r(sum) if year == `k' & c100_hwTotNW == `q' & hwTotNW !=. 	// sum_c10_hsavingW = saving amount per wealth percentile (weighted, constant within wealth  deciles)
			}
		}		
		*** special groups
		gen sum_top1_hwealthW =.
			foreach k of numlist /*1996/2012*/ $year {
				sum hwTotNW [aw=sw] if year == `k' & c100_hwTotNW == 100
				replace sum_top1_hwealthW = r(sum) if year == `k' 										// analog oben
			}
		gen sum_top5less1_hwealthW =.
			foreach k of numlist /*1996/2012*/ $year {
				sum hwTotNW [aw=sw] if year == `k' & c20_hwTotNW == 20 & c100_hwTotNW != 100
				replace sum_top5less1_hwealthW = r(sum) if year == `k'
			}			
		gen sum_top10less5_hwealthW =.
			foreach k of numlist /*1996/2012*/ $year {
				sum hwTotNW [aw=sw] if year == `k' & c10_hwTotNW == 10 & c20_hwTotNW != 20
				replace sum_top10less5_hwealthW = r(sum) if year == `k'
			}			
*	

	
	
		*** for income (including)
		set more off
		gen tothwealthI =.
		foreach k of numlist /*1996/2012*/ $year {
			sum hwTotNW [aw=sw] if year == `k'
			replace tothwealthI = r(sum) if year == `k' 												// total saving amount per year (weighted, constant across all hhs)
		}
	*
		gen sum_c10_hwealthI =.		// JS: entspricht monthly hh saving amount (sum over all hhs per income decile)
		foreach q of numlist 1/10 {
			foreach k of numlist /*1996/2012*/ $year {
				sum hwTotNW [aw=sw] if year == `k' & c10_hincNetY == `q'
				replace sum_c10_hwealthI = r(sum) if year == `k' & c10_hincNetY == `q' 				// saving amount per INCOME decile (weighted, constant within income deciles)
			}
		}	
		gen sum_c20_hwealthI =.
		foreach q of numlist 1/20 {
			foreach k of numlist 1996/2012 {
				sum hwTotNW [aw=sw] if year == `k' & c20_hincNetY == `q'
				replace sum_c20_hwealthI = r(sum) if year == `k' & c20_hincNetY == `q' 				// analog für Vingtile
			}
		}	
		gen sum_c100_hwealthI =.
		foreach q of numlist 1/100 {
			foreach k of numlist /*1996/2012*/ $year {
				sum hwTotNW [aw=sw] if year == `k' & c100_hincNetY == `q'
				replace sum_c100_hwealthI = r(sum) if year == `k' & c100_hincNetY == `q' 			// wie oben
			}
		}	
		*** special groups
		gen sum_top1_hwealthI =.
			foreach k of numlist /*1996/2012*/ $year {
				sum hwTotNW [aw=sw] if year == `k' & c100_hincNetY == 100
				replace sum_top1_hwealthI = r(sum) if year == `k'
			}
		gen sum_top5less1_hwealthI =.
			foreach k of numlist /*1996/2012*/ $year {
				sum hwTotNW [aw=sw] if year == `k' & c20_hincNetY == 20 & c100_hincNetY != 100
				replace sum_top5less1_hwealthI = r(sum) if year == `k'
			}			
		gen sum_top10less5_hwealthI =.
			foreach k of numlist /*1996/2012*/ $year {
				sum hwTotNW [aw=sw] if year == `k' & c10_hincNetY == 10 & c20_hincNetY != 20
				replace sum_top10less5_hwealthI = r(sum) if year == `k'
			}			
*					
	

		
