set more off
set dp period
cap log close
log using "..\LogFiles\HSV-EVS_02_IncomeWealth_SQ.log", replace

// -------------------------------------------------------------------------------------------------
// Definitionen
// -------------------------------------------------------------------------------------------------

*** saving amount
cap drop 	savings
gen 		savings = hsavingM 

*** saving rates
cap drop 	srate
gen 		srate = (hsavingM/hincomeM) * 100

*** share in savings
cap drop 	sshareI
gen 		sshareI = savings/totsavI * 100

cap drop 	sshareW
gen 		sshareW = savings/totsavW * 100


*** Anteil der Netto-Einnahmen aus Vermögen am Netto-Haushaltseinkommen
cap drop 	hhnevrateI
gen 		hhnevrateI = (hhne_v_p/hincomeM) * 100

*** Anteil der Netto-Einnahmen aus Vermögen am Netto-Vermögen:
cap drop 	hhnevrateW
gen 		hhnevrateW = (hhne_v_p/hwTotNW) * 100 if /*hhne_v_p>= 0 &*/ hwTotNW >= 0
replace 	hhnevrateW = . if (hhnevrateW > 300 & hhnevrateW < .) 	//Setze Werte höher als 300% auf Missing, da unsinnig/wenig aussagekräftig. betrifft 0,9% der Fälle in der Stichrpobe.

* für Gewichtung der schuledenfreiehen HHe (s.u.)
cap drop 	hwTotNWpos
gen 		hwTotNWpos = hwTotNW if hwTotNW >= 0

* Bilde Variablen für die Gruppierung nach Einkommensklassen und Vermögensklassen sowie Anteile der Klassen am Gesamtkuchen
* bzgl. Ersparnis, HH-Nettoeinnahmen aus Vermögen, HH-Netto-Einkommen und HH-Nettovermögen:

	foreach varstub in hincNetY hwTotNW {
		if "`varstub'" == "hincNetY" {
		local varshort I
		}
		else if "`varstub'" == "hwTotNW" {
		local varshort W
		}
	
	* build group variable
	cap drop 	group`varshort'
	gen 		group`varshort' = c10_`varstub'
	replace 	group`varshort' = 20 			if c20_`varstub' == 20
	replace 	group`varshort' = 100 			if c100_`varstub' == 100	

		if "`varstub'" == "hincNetY" {
		lab var 	group`varshort' "Einkommensklassen"
		}
		else if "`varstub'" == "hwTotNW" {
		lab var 	group`varshort' "Vermögensklassen"
		}		

	cap lab drop 	group`varshort'
	lab def 		group`varshort' 	1 "1st decile class" 			///
										2 "2nd decile class" 			///
										3 "3rd decile class" 			///
										4 "4th decile class" 			///
										5 "5th decile class" 			///
										6 "6th decile class" 			///
										7 "7th decile class" 			///
										8 "8th decile class" 			///
										9 "9th decile class" 			///
										10 "91th-95th percentile class" 	///
										20 "96th-99th percentile class" 	///
										100 "100th percentile class"
	
	lab val			group`varshort' group`varshort'
	}

* Generiere Altersklassen für den Haupteinkommensbezieher:
cap drop 	alter1_cat
gen 		alter1_cat = 1		if alter1 >= 18 & alter1 <= 34
replace 	alter1_cat = 2		if alter1 >= 35 & alter1 <= 64
replace		alter1_cat = 3 		if alter1 >= 65 & alter1 <= 120

cap lab drop 	alter1_cat
lab def 		alter1_cat 	1 "18-34 years" 2 "35-64 years" 3 "65+ years"
lab val 		alter1_cat alter1_cat

tab alter1_cat,m

cap drop 	f_a1834
gen 		f_a1834 = (alter1_cat == 1) if alter1_cat < .

cap drop 	f_a3564
gen 		f_a3564 = (alter1_cat == 2) if alter1_cat < .

cap drop 	f_a6599
gen 		f_a6599 = (alter1_cat == 3) if alter1_cat < .

* Generiere höchsten beruflichen Abschluss des Haupteinkommensbeziehers:
recode 		ausbild_js1 (7 = 6) 																if year == 2003
recode 		ausbild_js1 (13 12 = 1) (11 10 = 2) (9 8 7= 3) (6 5 4 = 4) (3 2 = 5) (1 = 6)		if year == 2013
recode 		ausbild_js1 (11 10 = 1) (9 8 = 2) (7 6 = 3) (5 4 = 4) (3 2 = 5) (1 = 6) 			if year == 2008
recode 		ausbild_js1 (6 = 1) (5 = 2) (4 = 3) (3 = 4) (2 = 5) (1 = 6)

cap lab drop 	ausbild_js1
lab def 		ausbild_js1 	1 "(noch) kein beruflicher Abschluss" 						///
							2 "sonstiger beruflicher Abschluss (z.B. Anlernberuf)" 		///
							3 "berufliche Ausbildung/Berufsfachschule"					///
							4 "Meister-/Techniker-/Fachschule, Berufs-/Fachakademie"	///
							5 "Fachhochschule (auch Ing.schule)"						///
							6 "Hochschule"

lab val 		ausbild_js1 ausbild_js1							

* Generiere HH-Typ mit wenig Ausprägungen:
gen 		hhtyp18_js = 1 		if hhtyp18 >= 1 & hhtyp18 <= 2
replace 	hhtyp18_js = 2		if hhtyp18 >= 3 & hhtyp18 <= 7
replace 	hhtyp18_js = 3 		if (hhtyp18 >= 9 & hhtyp18 <= 10) | (hhtyp18 >= 21 & hhtyp18 <= 22)
replace 	hhtyp18_js = 4 		if (hhtyp18 >= 11 & hhtyp18 <= 18) | (hhtyp18 >= 23 & hhtyp18 <= 28)
replace 	hhtyp18_js = 5 		if hhtyp18 == 99

lab def 	hhtyp18_js 	1 "Single" 2 "Single mother/father" 3 "Couple w/o children" 4 "Couple w children" 5 "other"
lab val 	hhtyp18_js hhtyp18_js
	
// -------------------------------------------------------------------------------------------------
// Deskriptiva
// -------------------------------------------------------------------------------------------------

* Beachte Fallzahlen: 
table groupI year alter1_cat , c(n savings n srate n hhne_v_p n hhnevrateI n hhnevrateW)

* summary stats for income and wealth groups:
table groupI year [aw=sw], c(n hincNetY mean hincNetY median hincNetY sd hincNetY) format(%9.0f) row
table groupI year [aw=sw], c(min hincNetY max hincNetY) format(%9.0f) row

table groupW year [aw=sw], c(n hwTotNW mean hwTotNW median hwTotNW sd hwTotNW) format(%9.0f) row
table groupW year [aw=sw], c(min hwTotNW max hwTotNW) format(%9.0f) row







* Einige wenige spezielle Zahlen zum Schreiben:
tabstat	savings [aw = sw] 				if c10_hincNetY <=  5, stat(n mean) by(year)
tabstat	savings [aw = sw] 				if c10_hwTotNW  <=  5, stat(n mean) by(year)

tabstat srate 	[aw = sw * hincomeM] 	if c10_hincNetY <=  5, stat(n mean) by(year)
tabstat srate 	[aw = sw * hincomeM] 	if c10_hwTotNW  <=  5, stat(n mean) by(year)

tabstat srate 	[aw = sw * hincomeM] 	if c10_hincNetY == 10, stat(n mean) by(year)

tabstat hincomeM [aw = sw] 									 , stat(n p90 p95 p99) by(year)
tabstat hwTotNW  [aw = sw] 									 , stat(n p90 p95 p99) by(year)

tabstat savings  [aw = sw] if year == 2013, stat(n mean sum) by(groupI) format(%20.0f)
tabstat savings  [aw = sw] if year == 2008, stat(n mean sum) by(groupI) format(%20.0f)
tabstat savings  [aw = sw] if year == 2003, stat(n mean sum) by(groupI) format(%20.0f)

tabstat savings [aw = sw] if year == 2013, stat(n mean sum) by(groupW) format(%20.0f)
tabstat srate 	[aw = sw * hincomeM] 	if c100_hincNetY == 100, stat(n mean) by(year)
tabstat srate 	[aw = sw * hincomeM] 	if c100_hwTotNW == 100, stat(n mean) by(year)


* Hauptauswertungen:

mata: mata clear

	foreach varstub in hincNetY hwTotNW {
		if "`varstub'" == "hincNetY" {
		local varshort I
		}
		else if "`varstub'" == "hwTotNW" {
		local varshort W
		}

		foreach y of varlist savings srate sshareI sshareW {

			if "`y'" == "savings" | "`y'" == "hhne_v_p" {
			local weight	[aw = sw]			
			local contents 	c(n `y' 	mean `y' 	p50 `y' 	sd `y')
			local format 	format(%9,0f)
			local bootstrap bootstrap _b, reps(1000) seed(12345) force:
			}
			else if "`y'" == "srate" | "`y'" == "hhnevrateI" {
			local weight	[aw = sw * hincomeM]
			local contents 	c(n `y' 	mean `y' 	p50 `y' 	sd `y')
			local format 	format(%9,1f)	
			local bootstrap bootstrap _b, reps(1000) seed(12345) force:	
			}
			else if "`y'" == "hhnevrateW" {
			local weight	[aw = sw * hwTotNWpos]
			local contents 	c(n `y' 	mean `y' 	p50 `y' 	sd `y')
			local format 	format(%9,1f)	
			local bootstrap bootstrap _b, reps(1000) seed(12345) force:	
			}			
			else if regexm("`y'", "share") == 1 {
			local weight	[aw = sw]
			local contents 	c(n `y' 	sum `y'					sd `y')
			local format 	format(%9,1f)	
			local bootstrap bootstrap _b, reps(1000) seed(12345) force:				
			}

			foreach s in f_alle /*f_a1834 f_a3564 f_a6599*/ {

			di "y = `y', gruppiert nach group`varshort', weight = `weight', s = `s':"	

				if regexm("`y'", "share") == 0 {
					table 	group`varshort' 	year	`weight' if `s' == 1, `contents' `format' row scol
				}
				else {
					if substr("`y'", -1, .) == "`varshort'" {
						foreach year of numlist $year {
						di "year = `year':"
						tabstat `y' `weight' 				if year == `year', stat(n sum mean sd) by(group`varshort')		
						
						levelsof group`varshort', clean local(group`varshort'_welt)
						cap mat drop w_`year'_group`varshort'
							foreach grouplevel of local group`varshort'_welt {
							qui sum `y' `weight'		if year == `year' & group`varshort' == `grouplevel'
							matrix w_`year'_group`varshort' = (nullmat(w_`year'_group`varshort'), r(sum_w))
							}

						mata: w_`year'_group`varshort' = st_matrix("w_`year'_group`varshort'")
						mata: w_`year'_group`varshort'
						}
					}
					else {
					continue, break
					}
				}
	
			di _n(2)

				foreach year of numlist $year {
					if !(regexm("`y'", "share") == 1 & substr("`y'", -1, .) != "`varshort'") {

					`bootstrap' mean 	`y' 	`weight' 	if year == `year' & `s' == 1, over(group`varshort')		
	        		*scalar 	`y'_`varshort'_`year'_`s'_n = `e(N)'
					est sto `y'_`varshort'_`year'_`s'
					
					* calculate result matrices in mata:
						if regexm("`y'", "share") {							
						mata: b_`year'_group`varshort' = st_matrix("e(b)")
						mata: b_w_`year'_group`varshort' = w_`year'_group`varshort' :* b_`year'_group`varshort'

						mata: ci_percentile_`year'_group`varshort' = st_matrix("e(ci_percentile)")
						mata: ci_percentile_w_`year'_group`varshort' = w_`year'_group`varshort' :* ci_percentile_`year'_group`varshort'

						* convert mata result matrices to Stata matrices:
						mata: st_matrix("b_w_`year'_group`varshort'", b_w_`year'_group`varshort')
						mata: st_matrix("ci_percentile_w_`year'_group`varshort'", ci_percentile_w_`year'_group`varshort')
						matrix rownames ci_percentile_w_`year'_group`varshort' = ll ul
						}
					}
					else {
					continue, break
					}        
				}		
			}

		di _n(4)
		}
	}

* repost original estimates with modified matrices:
	cap program drop my_erepost
	program define my_erepost, eclass
	est rest `1'
	est
	ereturn repost b = `2'
	ereturn matrix ci_percentile = `3'
	*matrix ci_percentile = `3'
	est
	est sto `1'
	end 



	foreach year of numlist $year {
	my_erepost sshareI_I_`year'_f_alle b_w_`year'_groupI ci_percentile_w_`year'_groupI
	my_erepost sshareW_W_`year'_f_alle b_w_`year'_groupW ci_percentile_w_`year'_groupW
	}


// -------------------------------------------------------------------------------------------------
// Graphen mit CIs
// -------------------------------------------------------------------------------------------------

local coeflabels1       = `"_subpop_1  = "1st decile class""'
local coeflabels2       = `"_subpop_2  = "2nd decile class""'
local coeflabels3       = `"_subpop_3  = "3rd decile class""'
local coeflabels4       = `"_subpop_4  = "4th decile class""'
local coeflabels5       = `"_subpop_5  = "5th decile class""'
local coeflabels6       = `"_subpop_6  = "6th decile class""'
local coeflabels7       = `"_subpop_7  = "7th decile class""'
local coeflabels8       = `"_subpop_8  = "8th decile class""'
local coeflabels9       = `"_subpop_9  = "9th decile class""'
local coeflabels10      = `"_subpop_10 = "91th-95th percentile class""'
local coeflabels11      = `"_subpop_11 = "96th-99th percentile class""'
local coeflabels12      = `"_subpop_12 = "100th percentile class""'
																																	
foreach y in savings srate sshare {
	foreach s in f_alle {
		if "`y'" == "savings" {
			local y1 `y'
			local y2 `y'
			local xtitle Euro
			local xlabel -20000(20000)70000
			local mlabfmt %3.0f
		}
		else if "`y'" == "srate" {
			local y1 `y'
			local y2 `y'
			local xtitle Per cent
			local xlabel -30(10)50
			local mlabfmt %3.1f
		}
		else if "`y'" == "sshare" {
			local y1 `y'I
			local y2 `y'W
			local xtitle Per cent

			local mlabfmt %3.1f
		}

		coefplot	(`y1'_I_2003_`s', mlabpos(9) msymbol(circle) label("Across Income") offset(.25)) (`y2'_W_2003_`s', mlabpos(3) msymbol(triangle) label("Across Wealth") offset(-.25)), bylabel(2003) 	///
				||	(`y1'_I_2008_`s', mlabpos(9) msymbol(circle) label("Across Income") offset(.25)) (`y2'_W_2008_`s', mlabpos(3) msymbol(triangle) label("Across Wealth") offset(-.25)), bylabel(2008)		///
				||	(`y1'_I_2013_`s', mlabpos(9) msymbol(circle) label("Across Income") offset(.25)) (`y2'_W_2013_`s', mlabpos(3) msymbol(triangle) label("Across Wealth") offset(-.25)), bylabel(2013)		///
				||																																								, byopts(row(1) xrescale) ///
																																												ci(ci_percentile) legend(rows(1)) xline(0) 		///
																																												xtitle("`xtitle'") mlabel format(`mlabfmt') mlabposition(12)  			///
																																												mlabgap(*1) ysize(8) xsize(12) xlabel(`xlabel', format(%9.0f) angle(90))				///
																																												coeflabels(`coeflabels1' `coeflabels2' `coeflabels3' `coeflabels4' `coeflabels5' `coeflabels6' `coeflabels7' `coeflabels8' `coeflabels9' `coeflabels10' `coeflabels11' `coeflabels12', nobreak) 	///
																																												mlabsize(small)
																																												
																																						
		graph export 		"..\graph\\`y'IW_`s'.png", replace
		graph export 		"..\graph\\`y'IW_`s'.pdf", replace
	}
}


// -------------------------------------------------------------------------------------------------
// Regressionen für savings, saving rate und share in savings
// -------------------------------------------------------------------------------------------------

	foreach y of varlist savings srate sshareI sshareW {
		if "`y'" == "savings" {
			local weight sw
			local b 3
			local se 3
		}
		else if "`y'" == "srate" {
			local weight sw*hincomeM
			local b 1
			local se 1
		}
		else if "`y'" == "sshareI" | "`y'" == "sshareW" {
			local weight sw
			local b 8
			local se 8
		}
		foreach group in I W {
			regress `y' i.group`group' ib2013.year [aw=`weight'], vce(robust)
			est sto `y'_`group'1			
			regress `y' i.group`group' ib2013.year i.alter1_cat i.ausbild_js1 [aw=`weight'], vce(robust)
			est sto `y'_`group'2
			regress `y' i.group`group' ib2013.year i.alter1_cat i.ausbild_js1 i.hhtyp18_js [aw=`weight'], vce(robust)
			est sto `y'_`group'3
		}
		regress `y' i.groupI i.groupW ib2013.year i.alter1_cat i.ausbild_js1 [aw=`weight'], vce(robust)
		est sto `y'_IW2
		regress `y' i.groupI i.groupW ib2013.year i.alter1_cat i.ausbild_js1 i.hhtyp18_js [aw=`weight'], vce(robust)
		est sto `y'_IW3

	esttab `y'_I? `y'_W? `y'_IW? using "..\rtf\\mainregs_`y'.rtf", 	replace onecell b(`b') se(`se')	///
			                        				    star(* 0.1 ** 0.05 *** 0.01) 						///
			                        				    scalars(N r2_a) sfmt(%9.0g %9.3f)    							///
			                        				    nobaselevels 										///
			                        				    label												///
			                        				    compress varwidth(25) modelwidth(18) 				///
			                        				    nonotes nonumbers mtitles nodepvars gaps   			///
			                        				    addnotes("*/**/*** = significant at the 10/5/1% level." 	///
			                        				    "Source: EVS, own calculations. Standard errors robust against heteroskedasticity.")
	}



// -------------------------------------------------------------------------------------------------
// Gemeinsame Verteilung von Einkommen und Vermögen
// -------------------------------------------------------------------------------------------------

tab 	c10_hincNetY c10_hwTotNW if year == 2013 [iw = sw], nofreq col

tab 	c10_hincNetY c10_hwTotNW if year == 2013 [iw = sw], nofreq row

// -------------------------------------------------------------------------------------------------
// Vergleich mit anderen Studien
// -------------------------------------------------------------------------------------------------

tabstat	aqbe_ij hincNetY [aw = sw], stat(n p99 p95 p90) by(year)

cap drop top10 top5 top1
gen top10 = .
gen top5 = .
gen top1 = .

	foreach year of numlist 2003 2008 2013 {

	_pctile aqbe_ij [aw = sw] if year == `year', percentiles(90 95 99)

	replace 	top10 = (aqbe_ij > r(r1))	if aqbe_ij < . & year == `year'
	replace 	top5  = (aqbe_ij > r(r2))	if aqbe_ij < . & year == `year'
	replace 	top1  = (aqbe_ij > r(r3))	if aqbe_ij < . & year == `year'
	}



tabstat aqbe_ij  if year == 2008, stat(n min max) by(top10)
tabstat aqbe_ij  if year == 2008, stat(n min max) by(top5)
tabstat aqbe_ij  if year == 2008, stat(n min max) by(top1)
* OK.

	foreach year of numlist 2008 {
		foreach topgroup in 10 5 1 {
		di "year = `year', topgroup = `topgroup':"
		tabstat aqbe_ij [aw = sw] if year == `year', stat(n mean sum) by(top`topgroup') format(%15.0f)
		di _n(4)
		}
	}


	foreach year of numlist 2008 {
		foreach topgroup in 10 5 1 {
		di "year = `year', topgroup = `topgroup':"
		tabstat aqne_ij [aw = sw] if year == `year', stat(n mean sum) by(top`topgroup') format(%15.0f)
		di _n(4)
		}
	}	
	
// -------------------------------------------------------------------------------------------------
// Inputparameter für Simulation
// -------------------------------------------------------------------------------------------------

cap drop 	hincNetM
gen			hincNetM = hincNetY / 12
lab var		hincNetM "Household net income per month"

drop 		if hincNetM > 18000 & hincNetM < .	// ein paar Leute kommen mit Boni etc. doch auf ein wenig mehr als 18000 pro Monat.


* - Saving rates der unteren 90/95/99 Prozent auf der Einkommensskala:

tabstat	srate [aw = sw * hincomeM] if  c10_hincNetY <=  9 & year == 2008, stat(n mean min max) by( c10_hincNetY)
tabstat	srate [aw = sw * hincomeM] if  c20_hincNetY <= 19 & year == 2008, stat(n mean min max) by( c20_hincNetY)
tabstat	srate [aw = sw * hincomeM] if c100_hincNetY <= 99 & year == 2008, stat(n mean min max)

* - Saving rate der oberen 10%:
tabstat	srate [aw = sw * hincomeM] if  c10_hincNetY == 10 & year == 2008, stat(n mean min max) by( c10_hincNetY)


* - Aggregierte Sparquote:
mean srate [aw = sw * hincomeM] if 						year == 2008
	
* - Group means der Top10/5/1% of income distribution bzgl. hhnet income (EVS, as-is):
tabstat	hincNetM [aw = sw] if  c100_hincNetY >=  91 & c100_hincNetY < . & year == 2008, stat(n mean min max) by(c100_hincNetY)	
tabstat	hincNetM [aw = sw] if  c100_hincNetY >=  96 & c100_hincNetY < . & year == 2008, stat(n mean min max) by(c100_hincNetY)	
tabstat	hincNetM [aw = sw] if  c100_hincNetY >= 100 & c100_hincNetY < . & year == 2008, stat(n mean min max) by(c100_hincNetY)	


// -------------------------------------------------------------------------------------------------
// Schätzung eines Modells für Sparquoten
// -------------------------------------------------------------------------------------------------

	foreach poly of numlist 1(1)8 {
	cap drop 	hincNetM`poly'
	gen 		hincNetM`poly' = hincNetM^`poly'
	
	local 		xlist = "`xlist'" + " " + "hincNetM`poly'"
	
	regress		srate `xlist' [aw = sw * hincNetM] 	if year == 2013 & srate >= -100 & srate <= 100, vce(robust)
	
	cap drop 	srate_hat`poly'
	predict 	srate_hat`poly', xb
	
	cap drop 	resid`poly'
	predict 	resid`poly', resid
		
	est sto		reg`poly'	
	
	table 		groupI [aw = sw * hincomeM] if e(sample), c(mean srate mean srate_hat`poly' mean resid`poly') row
	di _n(4)
	}

*=> Wähle das Modell mit Polynom 3. Grades, da die Residuen	dort im Mittel über die Einkommensgruppen meist am geringsten sind.
* (Oft sind aber auch die unterschiede zum nächsten Modell nur minimal.)

cap drop 		lnhincNetM
gen 			lnhincNetM = ln(hincNetM)

regress		srate lnhincNetM [aw = sw * hincNetM] 	if year == 2013 & srate >= -100 & srate <= 100, vce(robust)
est sto ln




local coeflabels1       = `"hincNetM1  "income^1""'
local coeflabels2       = `"hincNetM2  "income^2""'
local coeflabels3       = `"hincNetM3  "income^3""'
local coeflabels4       = `"hincNetM4  "income^4""'
local coeflabels5       = `"hincNetM5  "income^5""'
local coeflabels6       = `"hincNetM6  "income^6""'
local coeflabels7       = `"hincNetM7  "income^7""'
local coeflabels8       = `"hincNetM8  "income^8""'
local coeflabels9       = `"lnhincNetM  "ln(income)""'

esttab ln reg*	using "..\rtf\regpolys.rtf", b(3) se(3) scalar(N r2_a rmse aic bic)				///
			                        	replace 											///
			                        	onecell nogaps	 									///
			                        	star(* 0.1 ** 0.05 *** 0.01) 						///
			                        	sfmt(%9.0g)    										///
			                        	nobaselevels 										///
			                        	coeflabels(`coeflabels1' `coeflabels2' `coeflabels3' `coeflabels4' `coeflabels5' `coeflabels6' `coeflabels7' `coeflabels8' `coeflabels9')							///
			                        	compress varwidth(25) modelwidth(18) 				///
			                        	nonotes nonumbers mtitles nodepvars    			///
			                        	addnotes("*/**/*** = significant at the 10/5/1% level." 	///
			                        	"Source: EVS, own calculations. Monthly income used as regressors, 2013 prices. Standard errors robust against heteroskedasticity.")
			

* Schätze das Modell mit richtigem polynom nochmals für die predictions:
reg 		srate 	hincNetM1 	///
					c.hincNetM1#c.hincNetM1 ///
					c.hincNetM1##c.hincNetM1#c.hincNetM1 		[aw = sw * hincNetM] if year == 2013 & srate >= -100 & srate <= 100, vce(robust)

est sto		poly3

cap drop	srate_hatpoly3
predict 	srate_hatpoly3, xb

cap drop 	residpoly3
predict 	residpoly3, resid

table 		groupI [aw = sw * hincomeM] if e(sample), c(mean srate mean srate_hatpoly3 mean residpoly3) row
tabstat		hincNetM1 [aw = sw] if e(sample), stat(n mean min max) by(groupI)
* Ok.

/*
reg 		srate 	hincNetM1 	///
					c.hincNetM1#c.hincNetM1 ///
					c.hincNetM1##c.hincNetM1#c.hincNetM1 i.alter1_cat i.ausbild_js1 /*i.hhtyp18_js*/ 		[aw = sw * hincNetM] if year == 2013 & srate >= -100 & srate <= 100, vce(robust)

est sto		poly3aug

cap drop	srate_hatpoly3aug
predict 	srate_hatpoly3aug, xb

cap drop 	residpoly3aug
predict 	residpoly3aug, resid

table 		groupI [aw = sw * hincomeM] if e(sample), c(mean srate mean srate_hatpoly3aug mean residpoly3aug) row
tabstat		hincNetM1 [aw = sw] if e(sample), stat(n mean min max) by(groupI)

*=> die Erweiterung um zusätzliche Variablen bringt zwar insgesamt einen besseren Fit, aber die Prädiktion für die einzelnen Dezile wird meist schlechter und nur selten besser.
*   Un wenn sie besser wird, dann auch nicht immer um viel, aber im 1., 5. und 6. EK-Dezil wird sie um einiges schlechter. Bleibe daher beim bisherigen Modell. Das gilt umso mehr,
* wennman auch noch den HH-Typ reinnimmt. (Und auch, wenn man groupW noch dazunimmt. Weitere Experimente in der Richtung wurden nicht unternommen.)
*/

* letzte Erweiterung, incl. Wealth:
reg 		srate 	hincNetM1 	///
					c.hincNetM1#c.hincNetM1 ///
					c.hincNetM1##c.hincNetM1#c.hincNetM1 i.alter1_cat i.ausbild_js1 i.groupW i.hhtyp18_js 		[aw = sw * hincNetM] if year == 2013 & srate >= -100 & srate <= 100, vce(robust)

est sto poly3augW

cap drop	srate_hatpoly3augW
predict 	srate_hatpoly3augW, xb

cap drop 	residpoly3augW
predict 	residpoly3augW, resid

table 		groupI [aw = sw * hincomeM] if e(sample), c(mean srate mean srate_hatpoly3augW mean residpoly3augW) row
tabstat		hincNetM1 [aw = sw] if e(sample), stat(n mean min max) by(groupI)

* Schrittweiser Aufbau von Modellen
reg 		srate 	i.groupI  		[aw = sw * hincNetM] if year == 2013 & srate >= -100 & srate <= 100, vce(robust)
est sto 	m1

reg 		srate 	i.groupI i.hhtyp18_js  		[aw = sw * hincNetM] if year == 2013 & srate >= -100 & srate <= 100, vce(robust)
est sto 	m2

reg 		srate 	i.groupI i.hhtyp18_js i.groupW 		[aw = sw * hincNetM] if year == 2013 & srate >= -100 & srate <= 100, vce(robust)
est sto 	m3

reg 		srate 	i.groupI i.hhtyp18_js i.groupW i.alter1_cat	[aw = sw * hincNetM] if year == 2013 & srate >= -100 & srate <= 100, vce(robust)
est sto 	m4

reg 		srate 	i.groupI i.alter1_cat i.ausbild_js1 i.groupW i.hhtyp18_js 		[aw = sw * hincNetM] if year == 2013 & srate >= -100 & srate <= 100, vce(robust)
est sto 	m5

esttab 		m?, mtit scalars(r2_a)

reg 		srate 	i.groupW 	[aw = sw * hincNetM] if year == 2013 & srate >= -100 & srate <= 100, vce(robust)
est sto 	wealth

reg 		srate 	i.groupW i.alter1_cat 	[aw = sw * hincNetM] if year == 2013 & srate >= -100 & srate <= 100, vce(robust)
est sto 	wealth

reg 		srate 	i.groupW i.alter1_cat i.hhtyp18_js 	[aw = sw * hincNetM] if year == 2013 & srate >= -100 & srate <= 100, vce(robust)

reg 		srate 	i.groupW i.alter1_cat i.hhtyp18_js i.ausbild_js1	[aw = sw * hincNetM] if year == 2013 & srate >= -100 & srate <= 100, vce(robust)

reg 		srate 	i.groupW i.alter1_cat i.hhtyp18_js i.ausbild_js1 i.groupI	[aw = sw * hincNetM] if year == 2013 & srate >= -100 & srate <= 100, vce(robust)



reg 		srate 	i.groupI i.groupW#i.alter1_cat 	[aw = sw * hincNetM] if year == 2013 & srate >= -100 & srate <= 100, vce(robust)

by alter1_cat, s: reg 		srate 	i.groupI i.groupW 	[aw = sw * hincNetM] if year == 2013 & srate >= -100 & srate <= 100, vce(robust)

reg 		srate 	i.alter1_cat 	[aw = sw * hincNetM] if year == 2013 & srate >= -100 & srate <= 100, vce(robust)
est sto age
// -------------------------------------------------------------------------------------------------
// Projektion der Sparquoten
// -------------------------------------------------------------------------------------------------

est rest poly3

margins [aw = sw * hincomeM] if e(sample), 	  at(hincNetM1 = (1			///
														500			///
														1000		///
														1500		///
														2000		///
														2500		///
														3000		///
														3500		///
														4000		///
														4500		///
														5000		///
														5500		///
														6000        ///
														6500        ///
														7000        ///
														7500        ///
														8000        ///
														8068		/// EVS-Wert für Top10%														
														8500       ///
														9000       ///
														9036 		///	EVS+SOEP hypothethischer Wer für Top10%
														9500       ///
														9580		/// EVS-Wert für Top5%														
														10000       ///
														10500       ///
														10892 		/// EVS + SOEP + Tax hypo Wert für top10%														
														11000		///
														11017 		/// EVS + SOEP hypothetischer Wert für Top 5%
														11500       ///
														12000       ///
														12500       ///
														13000       ///
														13302		/// EVS-Wert Top1%														
														13500       ///
														14000       ///
														14500       ///
														15000       ///
														15424		///	EVS + SOEP + TAX hypo Wert für Top 5%
														15500       ///
														16000       ///
														16500		///
														17000		///
														17500		///
														17559 		/// EVS+SOEP hypo Wert für Top1%
														18000		/*
														18500		///
														19000		///
														19500		///
														20000*/)) 	post




coefplot, 	vertical  ///
			ytitle("Predicted saving rate in percent") xtitle("Household net income per month") 	///
			mlabel format(%9.1f) mlabposition(12) mlabgap(*5) mlabcolor(black) mlabangle(90) mlabsize(small)						///
			coeflabels(	1._at = 1	///
						2._at = 500 ///
						3._at = 1000 ///
						4._at = 1500 ///
						5._at = 2000 ///
						6._at = 2500 ///
						7._at = 3000 ///
						8._at = 3500 ///
						9._at = 4000 ///
						10._at = 4500 ///
						11._at = 5000 ///
						12._at = 5500 ///
						13._at = 6000 ///
						14._at = 6500 ///
						15._at = 7000 ///
						16._at = 7500 ///
						17._at = 8000 ///
						18._at = 8068		/// EVS-Wert für Top10%																				
						19._at = 8500 ///
						20._at = 9000 ///
						21._at = 9036 /// EVS+SOEP hypothetischer WErt
						22._at = 9500 ///
						23._at = 9580		/// EVS-Wert für Top5%																				
						24._at = 10000 ///
						25._at = 10500 ///
						26._at = 10892 /// EVS + SOEP + Tax hypo Wert für top10%
						27._at = 11000 ///
						28._at = 11017 /// EVS + SOEP hypo Wert
						29._at = 11500 ///
						30._at = 12000 ///
						31._at = 12500 ///
						32._at = 13000 ///
						33._at = 13302		/// EVS-Wert Top1%																				
						34._at = 13500 ///
						35._at = 14000 ///
						36._at = 14500 ///
						37._at = 15000 ///
						38._at = 15424 /// EVS + SOEP + TAX hypo Wert für Top 5%
						39._at = 15500 ///
						40._at = 16000 ///
						41._at = 16500 ///
						42._at = 17000 ///
						43._at = 17500 ///
						44._at = 17559 /// EVS+ SOEP hypo Wert
						45._at = 18000 		/*
						46._at = 18500		///
						47._at = 19000		///
						48._at = 19500		///
						49._at = 20000*/) 		xlabel(, angle(90) labsize(small)) ciopts(recast(rarea, fcolor( dimgray))) ///
												xline(17, lcolor(black) lpattern(solid)) xline(20, lcolor(blue) lpattern(dash)) xline(22, lcolor(black) lpattern(solid)) xline(25, lcolor(gray) lpattern(dot)) xline(27, lcolor(blue) lpattern(dash)) xline(32, lcolor(black) lpattern(solid)) xline(37, lcolor(gray) lpattern(dot)) xline(43, lcolor(blue) lpattern(dash)) 	/* ///
												text(-100 17 "EVS Top 10%", 					orientation(vertical) size(small) justification(left)) ///
												text(-100 20 "EVS & SOEP Top 10%", 			orientation(vertical) size(small) justification(left)) ///
												text(-100 22 "EVS Top 5%", 					orientation(vertical) size(small) justification(left)) ///
												text(-100 25 "EVS, SOEP & tex data Top 10%", orientation(vertical) size(small) justification(left)) ///
												text(-100 27 "EVS & SOEP Top 5%", 			orientation(vertical) size(small) justification(left)) ///
												text(-100 32 "EVS Top 1%", 					orientation(vertical) size(small) justification(left)) ///
												text(-100 37 "EVS, SOEP & tax data Top 5%", 	orientation(vertical) size(small) justification(left)) ///
												text(-100 43 "EVS & SOEP Top 1%", 			orientation(vertical) size(small) justification(left)) ///
												graphregion(margin(b=50))*/
	
	
	
graph export "..\graph\srate_proj_evs_soep_tax_below18000.png", replace
	
	

	
// -------------------------------------------------------------------------------------------------
// Postambel
// -------------------------------------------------------------------------------------------------

log close
exit
