    version         13.1

    clear

    set             more      off
    set             trace     off
    set             varabbrev off

    program         drop _all

    etime           , start

    global          master_path      "H:\Hiwi\STEFAN PREUSS\EVS"

    global          temp_path        "${master_path}\EVS - TEMP\"
    global          dta_path         "${master_path}\EVS - DTA GF3\"
    global          xlsx_path        "${master_path}\EVS - XLSX\"
    global          do_path          "${master_path}\EVS - DO\"
    global          log_path         "${master_path}\EVS - LOG\"
    global          csv_path         "${master_path}\EVS - CSV GF3\"

    local           genversion       "3R05"
    local           jahr             "2003"
    local           gf               "GF3"

    local           phase1 = 1
    local           phase2 = 1
    local           phase3 = 1

    local           vpi_aktuell = 0.848

    capture:        log close

    log             using "${log_path}\gen_ELASTIC_EVS_`gf'_`jahr'_`genversion'_SQ.log", replace

    if `phase1' {

        insheet         using "${csv_path}\EVS GF3 2003 [2016-02-24].csv", delimiter(";") clear case

        foreach v of varlist * {

            rename `v' `= "E03_" + upper("`v'")'

            }
        order           _all

        describe        _all
        summarize       _all

        save            "${dta_path}\ELASTIC_EVS_`gf'_`jahr'_`genversion'_raw_SQ.dta", replace
        etime

        }


    if `phase2' {

        use             "${dta_path}\ELASTIC_EVS_GF3_`jahr'_`genversion'_raw_SQ.dta", clear

        generate        surveyjahr          = `jahr'

        generate        hhnr                = E03_EF2U2
        generate float  hhrf                = E03_EF98
        generate        hhgroesse           = E03_EF78

*       U3 - Geburtsjahr ------------------------------------------------------------------------------------------------------------

        generate        e03_gjahr1          = E03_EF8U3
        generate        e03_gjahr2          = E03_EF9U3
        generate        e03_gjahr3          = E03_EF10U3
        generate        e03_gjahr4          = E03_EF11U3
        generate        e03_gjahr5          = E03_EF12U3
        generate        e03_gjahr6          = E03_EF13U3
        generate        e03_gjahr7          = E03_EF14U3
        generate        e03_gjahr8          = E03_EF15U3

*       U6 - Hchster Ausbildungsabschluss ----------------------------------------------------------------------------

        generate        e03_ausbild1        = E03_EF8U6
        generate        e03_ausbild2        = E03_EF9U6
        generate        e03_ausbild3        = E03_EF10U6
        generate        e03_ausbild4        = E03_EF11U6
        generate        e03_ausbild5        = E03_EF12U6
        generate        e03_ausbild6        = E03_EF13U6
        generate        e03_ausbild7        = E03_EF14U6
        generate        e03_ausbild8        = E03_EF15U6

*       H A R M O N I S I E R U N G

*       U3 - Geburtsjahr --------------------------------------------------------------------------------------------------------------


        foreach n of numlist 1(1)8 {

            generate        gjahr`n' =  e03_gjahr`n'

            }
			
*       E I N K O M M E N =========================================================================================================

        generate        hhbe            = E03_EF40 * 4     // HH-Bruttoeinkommen im Jahr
        generate        hhne            = E03_EF41 * 4     // HH-Nettoeinkommen im Jahr
        generate        hhbe_nsa        = E03_EF44 * 4     // HH-Bruttoeinkommen aus unselbstndiger Arbeit (inkl. Lohndeputate) im Jahr
        generate        hhbe_sa         = E03_EF45 * 4     // HH-Bruttoeinkommen aus selbstndiger Arbeit (inkl. Sachentnahmen) im Jahr
        generate        hhne_vuv        = E03_EF46 * 4     // HH-Nettoeinnahmen V+V im Jahr
        generate        hhne_v          = E03_EF47 * 4     // HH-Nettoeinnahmen aus Vermgen
        generate        hhbe_oet        = E03_EF48 * 4     // HH-Bruttoeinkommen aus ffentlichen Transferzahlungen im Jahr
        generate        hhbe_noet       = E03_EF49 * 4     // HH-Bruttoeinkommen aus nicht-ffentlichen Transferzahlungen im Jahr

        generate        qir             = E03_EF55         // Kalkulatorische Miete

*       A L T E R =================================================================================================================


        forvalues p = 1/8 {

            generate        alter`p' = `jahr' - e03_gjahr`p'
            }
		
*       H A U S H A L T S T Y P E N ===============================================================================================

        generate        hhtyp18         = E03_EF88

*       O E C D ===================================================================================================================


        forvalues p = 1/8 {

            generate        punter14`p'  = 0
            replace         punter14`p'  = 1 if alter`p' <= 14 & !missing( alter`p' )

            }

        egen            zdk         = rowtotal( punter14* )

        generate        oecdneu     = 1.0 + ( hhgroesse - zdk - 1 ) * 0.5 + zdk * 0.3

        cap drop        punter14*

*       I M P U T E D   R E N T =======================================================================================================

        generate        ir  = qir * 4


*       H A U S H A L T S E I N K O M M E N ===========================================================================================

        generate        hhme_i      = hhbe_nsa + hhbe_sa + hhne_v                   // HH-Markteinkommen  mit "imputed rent" im Jahr
        generate        hhbe_i      = hhme_i + hhbe_oet + hhbe_noet                 // HH-Bruttoeinkommen mit "imputed rent" im Jahr
        generate        hhne_i      = hhne                                          // HH-Nettoeinkommen  mit "imputed rent" im Jahr

        generate        hhbe_o      = hhbe_i - ir                                   // HH-Bruttoeinkommen ohne "imputed rent" im Jahr
        generate        hhne_o      = hhne_i - ir                                   // HH-Nettoeinkommen  ohne "imputed rent" im Jahr

        generate        aqbe_i      = hhbe_i  / oecdneu                             // quivalenzgewichtetes Bruttoeinkommen im Jahr mit imputed rent
        generate        aqne_i      = hhne_i  / oecdneu                             // quivalenzgewichtetes Nettoeinkommen  im Jahr mit imputed rent

        generate        aqbe_o      = hhbe_o  / oecdneu                             // quivalenzgewichtetes Bruttoeinkommen im Jahr ohne imputed rent
        generate        aqne_o      = hhne_o  / oecdneu                             // quivalenzgewichtetes Nettoeinkommen  im Jahr ohne imputed rent

*       V E R M ֠G E N   Z U M   1 . 1 . =========================================================================================

        generate        vimmovwert              = E03_EF467                 // Verkehrswert (Betrag in Euro)
        generate        vimmoschuldwert         = E03_EF459                 // Restschuld von Hypotheken, Baudarlehen u.䮍
        generate        vbausparwert            = E03_EF462                 // Bausparguthaben (Betrag in Euro)
        generate        vsparwert               = E03_EF466                 // H򨥠des Sparguthabens (Betrag in Euro
        generate        vanlagenwert            = E03_EF469                 // H򨥠des Guthabens (Betrag in Euro)
        generate        vaktienwert             = E03_EF472                 // Aktien (Betrag in Euro)
        generate        vrentenwert             = E03_EF473                 // Rentenwerte (Betrag in Euro)
        generate        vaktienfondswert        = E03_EF474                 // Aktienfonds (Betrag in Euro)
        generate        vsonstwertpapierewert   = E03_EF475                 // Sonst.Wertpapiere/Verm򧥮sbeteiligungen
        generate        vglaeubigerwert         = E03_EF478                 // H򨥠der verliehenen Betr娥 (in Euro)

        generate        vschuldkkwert           = E03_EF480                 // Restschuld v. Konsumentenkrediten (Betrag in Euro)

        generate        vvlebenwert             = E03_EF484 + E03_EF485     // Lebensversicherungen           (laut Anschreibung + imputierter Wert)
        generate        vvrentenwert            = E03_EF486 + E03_EF487     // private Rentenversicherungen   (laut Anschreibung + imputierter Wert)
        generate        vvsterbegeldwert        = E03_EF488 + E03_EF489     // Sterbegeldversicherungen       (laut Anschreibung + imputierter Wert)
        generate        vvausbildwert           = E03_EF490 + E03_EF491     // Ausbildungsversicherungen      (laut Anschreibung + imputierter Wert)
        generate        vvaussteuerwert         = E03_EF492 + E03_EF493     // Aussteuerversicherungen        (laut Anschreibung + imputierter Wert)

        generate        hhbvi                   = vimmovwert                                // Bruttoimmobilienverm򧥮

        generate        hhnvi                   = hhbvi                     ///             // Nettoimmobilienverm򧥮
                                                - vimmoschuldwert

        generate        vanlagen                = vsparwert                 ///
                                                + vbausparwert              ///
                                                + vanlagenwert

        generate        vwertpapiere            = vaktienwert               ///
                                                + vrentenwert               ///
                                                + vaktienfondswert          ///
                                                + vsonstwertpapierewert

        generate        vversicherung           = vvlebenwert               ///
                                                + vvrentenwert              ///
                                                + vvsterbegeldwert          ///
                                                + vvausbildwert

        generate        hhbvg                   = vanlagen                  ///             // Bruttogeldverm򧥮
                                                + vwertpapiere              ///
                                                + vversicherung             ///
                                                + vglaeubigerwert


        generate        hhnvg                   = hhbvg                     ///             // Nettogeldverm򧥮
                                                - vschuldkkwert

        generate        hhnv                    = hhnvi                     ///             // Nettoverm򧥮
                                                + hhnvg	
		
*       K O N S U M ===============================================================================================================

        generate        ersparnis   = E03_EF75 * 4          //  Ersparnis

        local konsumbereich         "ersparnis"

        foreach k of local konsumbereich {

            rename          `k'     `k'_j
            generate        `k'_p = `k'_j / `vpi_aktuell'
            }

*       P R E I S B E R E I N I G U N G 2013 := 100 ================================================================================================================================

        local ektyp     "hhbe_nsa hhbe_sa hhne_vuv hhne_v hhbe_oet hhbe_noet"

        foreach e of local ektyp {

            rename          `e'    `e'_j
            generate        `e'_p = `e'_j / `vpi_aktuell'
            }


        local ektyp     "hhbe_i hhne_i hhbe_o hhne_o aqbe_i aqne_i aqbe_o aqne_o"

        foreach e of local ektyp {

            rename          `e'    `e'j
            generate        `e'p = `e'j / `vpi_aktuell'
            }

        local vtyp      "hhbvi hhbvg hhnv hhnvi hhnvg"

        foreach v of local vtyp {

            rename          `v'    `v'_j
            generate        `v'_p = `v'_j / `vpi_aktuell'
            }			
			
		generate        f_alle      = 1	
			
        cap drop            E03_EF* e03_*
        cap drop            ibe_savj1 ibe_savj2 ibe_savj3 qir qsv sv svvjjn svvj hhbe_savj

        save            "${dta_path}\ELASTIC_EVS_`gf'_`jahr'_`genversion'_HH_F_SQ.dta", replace

        etime

        }



    if `phase3' {

        use             "${dta_path}\ELASTIC_EVS_`gf'_`jahr'_`genversion'_HH_F_SQ.dta", clear

        reshape         long    alter                 ///
                                ausbild               ///
                                , i( hhnr ) j( fam )

        cap drop                if missing( sex ) // Entfernung der Phantom HH-Mitglieder

        save                "${dta_path}\ELASTIC_EVS_`gf'_`jahr'_`genversion'_P_F_SQ.dta", replace

        etime

    }

    exit
