    version         13.1

    clear

    set             more      off
    set             trace     off
    set             varabbrev off

    program         drop _all

    etime           , start

    global          master_path      "H:\Hiwi\STEFAN PREUSS\EVS"

    global          temp_path        "${master_path}\EVS - TEMP\"
    global          dta_path         "${master_path}\EVS - DTA GF3\"
    global          xlsx_path        "${master_path}\EVS - XLSX\"
    global          do_path          "${master_path}\EVS - DO\"
    global          log_path         "${master_path}\EVS - LOG\"
    global          csv_path         "${master_path}\EVS - CSV GF3\"

    local           genversion       "3R05"
    local           jahr             "2008"
    local           gf               "GF3"

    local           phase1 = 1
    local           phase2 = 1
    local           phase3 = 1

    local           vpi_aktuell = 0.933


    capture:        log close

    log             using "${log_path}\gen_ELASTIC_EVS_`gf'_`jahr'_`genversion'_SQ.log", replace


    if `phase1' {

        insheet         using "${csv_path}\EVS GF3 2008 [2016-02-24].csv", delimiter(";") clear case

        foreach v of varlist * {

            rename `v' `= "E08_" + upper("`v'")'

            }
        order           _all
        save            "${dta_path}\ELASTIC_EVS_`gf'_`jahr'_`genversion'_raw_SQ.dta", replace
        etime

        }


    if `phase2' {

        use             "${dta_path}\ELASTIC_EVS_`gf'_`jahr'_`genversion'_raw_SQ.dta", clear

        generate        surveyjahr          = `jahr'

        generate        hhnr                = E08_EF2U2
        generate float  hhrf                = E08_EF87
        generate        hhgroesse           = E08_EF7

*       U3 - Geburtsjahr --------------------------------------------------------------------------------------------------------------

        generate        e08_gjahr1              = E08_EF8U3
        generate        e08_gjahr2              = E08_EF9U3
        generate        e08_gjahr3              = E08_EF10U3
        generate        e08_gjahr4              = E08_EF11U3
        generate        e08_gjahr5              = E08_EF12U3
        generate        e08_gjahr6              = E08_EF13U3
        generate        e08_gjahr7              = E08_EF14U3
        generate        e08_gjahr8              = E08_EF15U3

*       U7 - Hchster Ausbildungsabschluss ----------------------------------------------------------------------------------------

        generate        e08_ausbild1            = E08_EF8U7
        generate        e08_ausbild2            = E08_EF9U7
        generate        e08_ausbild3            = E08_EF10U7
        generate        e08_ausbild4            = E08_EF11U7
        generate        e08_ausbild5            = E08_EF12U7
        generate        e08_ausbild6            = E08_EF13U7
        generate        e08_ausbild7            = E08_EF14U7
        generate        e08_ausbild8            = E08_EF15U7

*       H A R M O N I S I E R U N G

*       U3 - Geburtsjahr --------------------------------------------------------------------------------------------------------------


        foreach n of numlist 1(1)8 {

            generate        gjahr`n' =  e08_gjahr`n'

            }

*       E I N K O M M E N =========================================================================================================

        generate        hhbe_nsa        = E08_EF50  * 4  // HH-Bruttoeinkommen aus unselbstndiger Arbeit im Jahr
        generate        hhbe_sa         = E08_EF51  * 4  // HH-Bruttoeinkommen aus selbstndiger Arbeit im Jahr
        generate        hhne_vuv        = E08_EF53  * 4  // HH-Nettoeinkommen V+V im Jahr
        generate        hhne_v          = E08_EF54  * 4  // HH-Nettoeinkommen aus Vermgen im Jahr
        generate        hhbe_oet        = E08_EF55  * 4  // HH-Bruttoeinkommen aus ffentlichen Transferzahlungen im Jahr
        generate        hhbe_noet       = E08_EF56  * 4  // HH-Bruttoeinkommen aus nicht-ffentlichen Transferzahlungen im Jahr
        generate        hhbe            = E08_EF57  * 4  // HH-Bruttoeinkommen im Jahr
        generate        hhne            = E08_EF58  * 4  // HH-Nettoeinkommen im Jahr

        generate        qir             = E08_EF77       // Kalkulatorische Meite


*       A L T E R =================================================================================================================


        forvalues p = 1/8 {

            generate        alter`p' = `jahr' - e08_gjahr`p'

            }
		
*       H A U S H A L T S T Y P E N ===============================================================================================

        generate        hhtyp18         = E08_EF88

*       O E C D ===================================================================================================================


        forvalues p = 1/8 {

            generate        punter14`p'  = 0
            replace         punter14`p'  = 1 if alter`p' <= 14 & !missing( alter`p' )

            }

        egen            zdk         = rowtotal( punter14* )

        generate        oecdneu     = 1.0 + ( hhgroesse - zdk - 1 ) * 0.5 + zdk * 0.3

        cap drop            punter14*

*       I M P U T E D   R E N T =======================================================================================================

        generate        ir  = qir * 4


*       H A U S H A L T S E I N K O M M E N ===========================================================================================

        generate        hhme_i      = hhbe_nsa + hhbe_sa + hhne_v                   // HH-Markteinkommen  mit "imputed rent" im Jahr
        generate        hhbe_i      = hhme_i + hhbe_oet + hhbe_noet                 // HH-Bruttoeinkommen mit "imputed rent" im Jahr
        generate        hhne_i      = hhne                                          // HH-Nettoeinkommen  mit "imputed rent" im Jahr

        generate        hhbe_o      = hhbe_i - ir                                   // HH-Bruttoeinkommen ohne "imputed rent" im Jahr
        generate        hhne_o      = hhne_i - ir                                   // HH-Nettoeinkommen  ohne "imputed rent" im Jahr

        generate        aqbe_i      = hhbe_i  / oecdneu                             // quivalenzgewichtetes Bruttoeinkommen im Jahr mit imputed rent
        generate        aqne_i      = hhne_i  / oecdneu                             // quivalenzgewichtetes Nettoeinkommen  im Jahr mit imputed rent

        generate        aqbe_o      = hhbe_o  / oecdneu                             // quivalenzgewichtetes Bruttoeinkommen im Jahr ohne imputed rent
        generate        aqne_o      = hhne_o  / oecdneu                             // quivalenzgewichtetes Nettoeinkommen  im Jahr ohne imputed rent

*       V E R M ֠G E N   Z U M   1 . 1 . =========================================================================================

        generate        vimmovwert                  = E08_EF467                 // Verkehrswert (Betrag in Euro)
        generate        vimmoschuldwert             = E08_EF469                 // Restschuld von Hypotheken, Baudarlehen u.䮍

        generate        vsparwert                   = E08_EF471                 // H򨥠des Sparguthabens (Betrag in Euro
        generate        vbausparwert                = E08_EF475                 // Bausparguthaben (Betrag in Euro)
        generate        vanlagenwert                = E08_EF479                 // H򨥠des Guthabens (Betrag in Euro)
        generate        vaktienwert                 = E08_EF482                 // Aktien (Betrag in Euro)
        generate        vrentenwert                 = E08_EF483                 // Rentenwerte (Betrag in Euro)
        generate        vaktienfondswert            = E08_EF484                 // Aktienfonds (Betrag in Euro)
        generate        vimmobilienfondswert        = E08_EF485                 // Immobilienfonds (Betrag in Euro)
        generate        vrentenfondswert            = E08_EF486                 // Rentenfonds (Betrag in Euro)
        generate        vgeldmarktfondswert         = E08_EF487                 // Geldmarktfonds (Betrag in Euro)
        generate        vsonstfondswert             = E08_EF488                 // sonstige Fonds (Betrag in Euro)
        generate        vsonstwertpapierewert       = E08_EF489                 // Sonst.Wertpapiere/Verm򧥮sbeteiligungen
        generate        vglaeubigerwert             = E08_EF492                 // H򨥠der verliehenen Betr娥 (in Euro)

        generate        vschuldkkwert               = E08_EF494                 // Restschuld v. Konsumentenkrediten (Betrag in Euro)
        generate        vschuldakwert               = E08_EF496                 // Restschuld von Ausbildungskrediten (einschl. Zinsen)
        generate        vvlebenwert                 = E08_EF500 + E08_EF501     // Lebensversicherungen         (laut Anschreibung + imputierter Wert)
        generate        vvrentenwert                = E08_EF502 + E08_EF503     // private Rentenversicherungen (laut Anschreibung + imputierter Wert)
        generate        vvsterbegeldwert            = E08_EF504 + E08_EF505     // Sterbegeldversicherungen     (laut Anschreibung + imputierter Wert)
        generate        vvausbildwert               = E08_EF506 + E08_EF507     // Ausbildungsversicherungen    (laut Anschreibung + imputierter Wert)
        generate        vvaussteuerwert             = E08_EF508 + E08_EF509     // Aussteuerversicherungen      (laut Anschreibung + imputierter Wert)

        generate        hhbvi                       = vimmovwert                                // Bruttoimmobilienverm򧥮

        generate        hhnvi                       = hhbvi                     ///             // Nettoimmobilienverm򧥮
                                                    - vimmoschuldwert

        generate        vanlagen                    = vsparwert                 ///
                                                    + vbausparwert              ///
                                                    + vanlagenwert

        generate        vwertpapiere                = vaktienwert               ///
                                                    + vrentenwert               ///
                                                    + vaktienfondswert          ///
                                                    + vimmobilienfondswert      ///
                                                    + vrentenfondswert          ///
                                                    + vgeldmarktfondswert       ///
                                                    + vsonstfondswert           ///
                                                    + vsonstwertpapierewert

        generate        vversicherung               = vvlebenwert               ///
                                                    + vvrentenwert              ///
                                                    + vvsterbegeldwert          ///
                                                    + vvausbildwert

        generate        hhbvg                       = vanlagen                  ///             // Bruttogeldverm򧥮
                                                    + vwertpapiere              ///
                                                    + vversicherung             ///
                                                    + vglaeubigerwert

        generate        hhnvg                       = hhbvg                     ///             // Nettogeldverm򧥮
                                                    - vschuldkkwert             ///
                                                    - vschuldakwert

        generate        hhnv                        = hhnvi                     ///             // Nettoverm򧥮
                                                    + hhnvg


*       K O N S U M ===============================================================================================================

        generate        ersparnis   = E08_EF85 * 4          //  Ersparnis

        local konsumbereich         "ersparnis"

        foreach k of local konsumbereich {

            rename          `k'     `k'_j
            generate        `k'_p = `k'_j / `vpi_aktuell'
            }

*       P R E I S B E R E I N I G U N G 2013 := 100 ================================================================================================================================


        local ektyp     "hhbe_nsa hhbe_sa hhne_vuv hhne_v hhbe_oet hhbe_noet"

        foreach e of local ektyp {

            rename          `e'    `e'_j
            generate        `e'_p = `e'_j / `vpi_aktuell'
            }


        local ektyp     "hhbe_i hhne_i hhbe_o hhne_o aqbe_i aqne_i aqbe_o aqne_o"

        foreach e of local ektyp {

            rename          `e'    `e'j
            generate        `e'p = `e'j / `vpi_aktuell'
            }
        
		local vtyp      "hhbvi hhbvg hhnv hhnvi hhnvg"

        foreach v of local vtyp {

            rename          `v'    `v'_j
            generate        `v'_p = `v'_j / `vpi_aktuell'
            }
			
		generate        f_alle      = 1	
		
        cap drop            E08_EF* e08_*
        cap drop            ibe_savj1 ibe_savj2 ibe_savj3 qir qsv sv svvjjn svvj hhbe_savj

        save            "${dta_path}\ELASTIC_EVS_`gf'_`jahr'_`genversion'_HH_F_SQ.dta", replace

        etime

        }



    if `phase3' {

        use                 "${dta_path}\ELASTIC_EVS_`gf'_`jahr'_`genversion'_HH_F_SQ.dta", clear

        reshape             long    alter                 ///
                                    ausbild               ///
                                    , i( hhnr ) j( fam )

        cap drop                if missing( sex ) // Entfernung der Phantom HH-Mitglieder

        save                "${dta_path}\ELASTIC_EVS_`gf'_`jahr'_`genversion'_P_F_SQ.dta", replace

        etime

    }

    exit
