    version         13.1

    clear

    set             more      off
    set             trace     on
    set             varabbrev off

    program         drop _all

    etime           , start

    global          master_path  "H:\Hiwi\STEFAN PREUSS\EVS"

    global          temp_path    "${master_path}\EVS - TEMP\"
    global          dta_path     "${master_path}\EVS - DTA GF3\"
    global          xlsx_path    "${master_path}\EVS - XLSX\"
    global          do_path      "${master_path}\EVS - DO\"
    global          log_path     "${master_path}\EVS - LOG\"
    global          csv_path     "${master_path}\EVS - CSV GF3\"

    local           genversion   "3R05"
    local           jahr         "2013"
    local           gf           "GF3"

    local           phase1 = 1
    local           phase2 = 1
    local           phase3 = 1

    local           vpi_aktuell = 1.000


    capture:        log close

    log             using "${log_path}\gen_ELASTIC_EVS_`gf'_`jahr'_`genversion'_SQ.log", replace

    if `phase1' {

        insheet         using "${csv_path}\EVS GF3 2013 [2016-02-05].csv", delimiter(";") clear case

        foreach v of varlist * {

            rename `v' `= "E13_" + upper("`v'")'

            }
        order           _all
        save        "${dta_path}\ELASTIC_EVS_`gf'_`jahr'_`genversion'_raw_SQ.dta", replace
        etime

        }


    if `phase2' {

        use         "${dta_path}\ELASTIC_EVS_GF3_`jahr'_`genversion'_raw_SQ.dta", clear

        generate        surveyjahr          = `jahr'

        generate        hhnr                = E13_EF2U2
        generate        hhrf                = E13_EF107
        generate        hhgroesse           = E13_EF7

*       U3 - Geburtsjahr ------------------------------------------------------------------------------------------------------------

        generate        e13_gjahr1              = E13_EF8U3
        generate        e13_gjahr2              = E13_EF9U3
        generate        e13_gjahr3              = E13_EF10U3
        generate        e13_gjahr4              = E13_EF11U3
        generate        e13_gjahr5              = E13_EF12U3
        generate        e13_gjahr6              = E13_EF13U3
        generate        e13_gjahr7              = E13_EF14U3
        generate        e13_gjahr8              = E13_EF15U3

*       U7 - Hchster Ausbildungsabschluss ------------------------------------------------------------------------------------------

        generate        e13_ausbild1            = E13_EF8U7
        generate        e13_ausbild2            = E13_EF9U7
        generate        e13_ausbild3            = E13_EF10U7
        generate        e13_ausbild4            = E13_EF11U7
        generate        e13_ausbild5            = E13_EF12U7
        generate        e13_ausbild6            = E13_EF13U7
        generate        e13_ausbild7            = E13_EF14U7
        generate        e13_ausbild8            = E13_EF15U7

*       H A R M O N I S I E R U N G  ---------------------------------------------------------------------------------------

*       U3 - Geburtsjahr --------------------------------------------------------------------------------------------------------------


        foreach n of numlist 1(1)8 {

            generate        gjahr`n' =  e13_gjahr`n'

            }

*       E I N K O M M E N =========================================================================================================

        generate        hhbe_nsa        = E13_EF51 * 4      // HH-Bruttoeinkommen aus unselbstndiger Arbeit (inkl. Lohndeputate) im Jahr
        generate        hhbe_sa         = E13_EF52 * 4      // HH-Bruttoeinkommen aus selbstndiger Arbeit (inkl. Sachentnahmen) im Jahr
        generate        hhne_vuv        = E13_EF54 * 4      // HH-Nettoeinkommen V+V im Jahr
        generate        hhne_v          = E13_EF55 * 4      // HH-Nettoeinkommen aus Vermgen im Jahr
        generate        hhbe_oet        = E13_EF56 * 4      // HH-Bruttoeinkommen aus ffentlichen Transferzahlungen im Jahr
        generate        hhbe_noet       = E13_EF58 * 4      // HH-Bruttoeinkommen aus nicht-ffentlichen Transferzahlungen im Jahr
        generate        hhbe            = E13_EF61 * 4      // Haushaltsbruttoeinkommen (inkl. Arbeitgeberzuschsse/Zuschsse der RV-Trger zur freiw. GKV/PKV - analog zu 2008) im Jahr
        generate        hhne            = E13_EF64 * 4      // Haushaltsnettoeinkommen (inkl. Beitrge zur freiwilligen GKV/PKV - analog zu 2008) im Jahr

        generate        qir             = E13_EF77         // Kalkulatorische Miete

*       A L T E R ====================================================================================================Identische Merkmale


        forvalues p = 1/8 {

            generate        alter`p' = `jahr' - e13_gjahr`p'
            generate        istea`p' = ( alter`p' >= 15 & alter`p' <= 64 )

            }

*       H A U S H A L T S T Y P E N ===============================================================================================

         generate        hhtyp18         = E13_EF88

*       O E C D =========================================================================================================Identische Merkmale


        forvalues p = 1/8 {

            generate        punter14`p'  = 0
            replace         punter14`p'  = 1 if alter`p' <= 14 & !missing( alter`p' )

            }

        egen            zdk         = rowtotal( punter14* )
        generate        oecdneu     = 1.0 + ( hhgroesse - zdk - 1 ) * 0.5 + zdk * 0.3

        cap drop            punter14*

*       I M P U T E D   R E N T ======================================================================================================= =Identische Merkmale

        generate        ir  = qir * 4

*       H A U S H A L T S E I N K O M M E N ============================================================================================Identische Merkmale


        generate        hhme_i      = hhbe_nsa + hhbe_sa + hhne_v                   // HH-Markteinkommen  mit "imputed rent" im Jahr
        generate        hhbe_i      = hhme_i + hhbe_oet + hhbe_noet                 // HH-Bruttoeinkommen mit "imputed rent" im Jahr
        generate        hhne_i      = hhne                                          // HH-Nettoeinkommen  mit "imputed rent" im Jahr

        generate        hhbe_o      = hhbe_i - ir                                   // HH-Bruttoeinkommen ohne "imputed rent" im Jahr
        generate        hhne_o      = hhne_i - ir                                   // HH-Nettoeinkommen  ohne "imputed rent" im Jahr

        generate        aqbe_i      = hhbe_i  / oecdneu                             // quivalenzgewichtetes Bruttoeinkommen im Jahr mit imputed rent
        generate        aqne_i      = hhne_i  / oecdneu                             // quivalenzgewichtetes Nettoeinkommen  im Jahr mit imputed rent

        generate        aqbe_o      = hhbe_o  / oecdneu                             // quivalenzgewichtetes Bruttoeinkommen im Jahr ohne imputed rent
        generate        aqne_o      = hhne_o  / oecdneu                             // quivalenzgewichtetes Nettoeinkommen  im Jahr ohne imputed rent

*       V E R M ֠G E N   Z U M   1 . 1 . =========================================================================================

        generate        vimmovwert                  = E13_EF578         //  Summand     Verkehrswert (Betrag in Euro)
        generate        vimmoschuldwert             = E13_EF580         //              Restschuld von Hypotheken, Baudarlehen u.䮍
        generate        vsparwert                   = E13_EF582         //  Summand     H򨥠des Sparguthabens (Betrag in Euro)
        generate        vbausparwert                = E13_EF586         //  Summand     Bausparguthaben (Betrag in Euro)
        generate        vanlagenwert                = E13_EF590         //  Summand     H򨥠des Guthabens (Betrag in Euro)
        generate        vaktienwert                 = E13_EF593         //  Summand     Aktien (Betrag in Euro)
        generate        vrentenwert                 = E13_EF594         //  Summand     Rentenwerte (Betrag in Euro)
        generate        vaktienfondswert            = E13_EF595         //  Summand     Aktienfonds (Betrag in Euro)
        generate        vimmobilienfondswert        = E13_EF596         //  Summand     Immobilienfonds (Betrag in Euro)
        generate        vrentenfondswert            = E13_EF597         //  Summand     Rentenfonds (Betrag in Euro)
        generate        vgeldmarktfondswert         = E13_EF598         //  Summand     Geldmarktfonds (Betrag in Euro)
        generate        vsonstfondswert             = E13_EF599         //  Summand     sonstige Fonds (Betrag in Euro)
        generate        vsonstwertpapierewert       = E13_EF600         //  Summand     Sonst.Wertpapiere / Verm򧥮sbeteiligungen (in Euro)
        generate        vglaeubigerwert             = E13_EF603         //  Summand     H򨥠der verliehenen (nicht zur𣫧ezahlten) Betr娥 (in Euro)
        generate        vschuldkkwert               = E13_EF605         //  Summand     Restschuld von Konsumentenkred.(Betrag in Euro)
        generate        vschuldakwert               = E13_EF607         //  Summand     Restschuld von Ausbildungskrediten (einschlieࠬich Zinsen) (Betrag in Euro)
        generate        vsonstschuldwert            = E13_EF610         //  Summand     H򨥠der sonstigen Verbindlichkeiten aus 2012
        generate        vvlebenwert                 = E13_EF612         //  Summand     Lebensversicherungen
        generate        vvrentenwert                = E13_EF613         //  Summand     private Rentenversicherungen
        generate        vvriesterrentenwert         = E13_EF614         //  Summand     Riesterrente
        generate        vvrueruprentenwert          = E13_EF615         //  Summand     R𲵰-/Basisrente
        generate        vvausbildwert               = E13_EF616         //  Summand     Ausbildungsversicherung
        generate        vvsterbegeldwert            = E13_EF617         //  Summand     Sterbegeldversicherung
        generate        vvunfallwert                = E13_EF618         //  Summand     Unfallversicherung mit Beitragsr𣫧ew婲


        generate        hhbvi                   = vimmovwert                                // Bruttoimmobilienverm򧥮

        generate        hhnvi                   = hhbvi                     ///             // Nettoimmobilienverm򧥮
                                                - vimmoschuldwert

        generate        vanlagen                = vsparwert                 ///
                                                + vbausparwert              ///
                                                + vanlagenwert

        generate        vwertpapiere            = vaktienwert               ///
                                                + vrentenwert               ///
                                                + vaktienfondswert          ///
                                                + vimmobilienfondswert      ///
                                                + vrentenfondswert          ///
                                                + vgeldmarktfondswert       ///
                                                + vsonstfondswert           ///
                                                + vsonstwertpapierewert

        generate        vversicherung           = vvlebenwert               ///
                                                + vvrentenwert              ///
                                                + vvsterbegeldwert          ///
                                                + vvausbildwert             ///
                                                + vvriesterrentenwert       ///
                                                + vvrueruprentenwert        ///
                                                + vvunfallwert

        generate        hhbvg                   = vanlagen                  ///             // Bruttogeldverm򧥮
                                                + vwertpapiere              ///
                                                + vversicherung             ///
                                                + vglaeubigerwert


        generate        hhnvg                   = hhbvg                     ///             // Nettogeldverm򧥮
                                                - vschuldkkwert             ///
                                                - vschuldakwert             ///
                                                - vsonstschuldwert

        generate        hhnv                    = hhnvi                     ///             // Nettoverm򧥮
                                                + hhnvg

        etime
		
*       K O N S U M ===============================================================================================================

        generate        ersparnis   = E13_EF105 * 4         //  Ersparnis

        local konsumbereich         "ersparnis"

        foreach k of local konsumbereich {

            rename          `k'     `k'_j
            generate        `k'_p = `k'_j / `vpi_aktuell'
            }

*       P R E I S B E R E I N I G U N G 2013 := 100 ===============================================================================


        local ektyp     "hhbe_nsa hhbe_sa hhne_vuv hhne_v hhbe_oet hhbe_noet"

        foreach e of local ektyp {

            rename          `e'    `e'_j
            generate        `e'_p = `e'_j / `vpi_aktuell'
            }


        local ektyp     "hhbe_i hhne_i hhbe_o hhne_o aqbe_i aqne_i aqbe_o aqne_o"

        foreach e of local ektyp {

            rename          `e'    `e'j
            generate        `e'p = `e'j / `vpi_aktuell'
            }
			
		local vtyp      "hhbvi hhbvg hhnv hhnvi hhnvg"

        foreach v of local vtyp {

            rename          `v'    `v'_j
            generate        `v'_p = `v'_j / `vpi_aktuell'
            }
		
		generate        f_alle      = 1	
		
        save            "${dta_path}\ELASTIC_EVS_`gf'_`jahr'_`genversion'_HH_F_raw_SQ.dta", replace

        cap drop            E13_EF*

        save            "${dta_path}\ELASTIC_EVS_`gf'_`jahr'_`genversion'_HH_F_SQ.dta", replace

        etime

        }



    if `phase3' {

        use         "${dta_path}\ELASTIC_EVS_`gf'_`jahr'_`genversion'_HH_F_SQ.dta", clear

        reshape         long    alter                 ///
                                ausbild               ///
                                , i( hhnr ) j( fam )

        cap drop                if missing( sex ) // Entfernung der Phantom HH-Mitglieder

        save            "${dta_path}\ELASTIC_EVS_`gf'_`jahr'_`genversion'_P_F_SQ.dta", replace

        etime

    }

    exit
